==> zio-aws-polly_2.13-5.17.129.3-sources.jar: zio/aws/polly/model/StartSpeechSynthesisTaskResponse.scala <==
package zio.aws.polly.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StartSpeechSynthesisTaskResponse(
    synthesisTask: Option[zio.aws.polly.model.SynthesisTask] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse = {
    import StartSpeechSynthesisTaskResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
      .builder()
      .optionallyWith(synthesisTask.map(value => value.buildAwsValue()))(
        _.synthesisTask
      )
      .build()
  }
  def asReadOnly
      : zio.aws.polly.model.StartSpeechSynthesisTaskResponse.ReadOnly =
    zio.aws.polly.model.StartSpeechSynthesisTaskResponse.wrap(buildAwsValue())
}
object StartSpeechSynthesisTaskResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.polly.model.StartSpeechSynthesisTaskResponse =
      zio.aws.polly.model.StartSpeechSynthesisTaskResponse(
        synthesisTask.map(value => value.asEditable)
      )
    def synthesisTask: Option[zio.aws.polly.model.SynthesisTask.ReadOnly]
    def getSynthesisTask
        : ZIO[Any, AwsError, zio.aws.polly.model.SynthesisTask.ReadOnly] =
      AwsError.unwrapOptionField("synthesisTask", synthesisTask)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
  ) extends zio.aws.polly.model.StartSpeechSynthesisTaskResponse.ReadOnly {
    override val synthesisTask
        : Option[zio.aws.polly.model.SynthesisTask.ReadOnly] = scala
      .Option(impl.synthesisTask())
      .map(value => zio.aws.polly.model.SynthesisTask.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
  ): zio.aws.polly.model.StartSpeechSynthesisTaskResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-polly_2.13-5.17.201.1-sources.jar: zio/aws/polly/model/StartSpeechSynthesisTaskResponse.scala <==
package zio.aws.polly.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartSpeechSynthesisTaskResponse(
    synthesisTask: Optional[zio.aws.polly.model.SynthesisTask] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse = {
    import StartSpeechSynthesisTaskResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
      .builder()
      .optionallyWith(synthesisTask.map(value => value.buildAwsValue()))(
        _.synthesisTask
      )
      .build()
  }
  def asReadOnly
      : zio.aws.polly.model.StartSpeechSynthesisTaskResponse.ReadOnly =
    zio.aws.polly.model.StartSpeechSynthesisTaskResponse.wrap(buildAwsValue())
}
object StartSpeechSynthesisTaskResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.polly.model.StartSpeechSynthesisTaskResponse =
      zio.aws.polly.model.StartSpeechSynthesisTaskResponse(
        synthesisTask.map(value => value.asEditable)
      )
    def synthesisTask: Optional[zio.aws.polly.model.SynthesisTask.ReadOnly]
    def getSynthesisTask
        : ZIO[Any, AwsError, zio.aws.polly.model.SynthesisTask.ReadOnly] =
      AwsError.unwrapOptionField("synthesisTask", synthesisTask)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
  ) extends zio.aws.polly.model.StartSpeechSynthesisTaskResponse.ReadOnly {
    override val synthesisTask
        : Optional[zio.aws.polly.model.SynthesisTask.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.synthesisTask())
        .map(value => zio.aws.polly.model.SynthesisTask.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.polly.model.StartSpeechSynthesisTaskResponse
  ): zio.aws.polly.model.StartSpeechSynthesisTaskResponse.ReadOnly =
    new Wrapper(impl)
}
